package com.factory.controller.web;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.web.entity.onsite.OnsiteItem;
import com.factory.web.entity.onsite.OnsiteItemReq;
import com.factory.web.entity.onsite.OnsiteItemRes;
import com.factory.web.service.onsite.OnsiteItemService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@Api(tags = "巡检项目设置")
@RestController
@RequestMapping("/benteler/onsite")
public class OnsiteItemController {

	@Autowired
	private OnsiteItemService onsiteItemService;

	@ApiOperation(value = "添加巡检项目")
	@PostMapping("/addOnsiteItem")
	public ResponseBean addOnsiteItem(@RequestBody OnsiteItemReq req) {
		OnsiteItem onsiteItem = OnsiteItem.builder()
				.workshopId(req.getWorkshopId())
				.itemContent(req.getItemContent())
				.typeFlag(req.getTypeFlag())
				.inspectionFlag(req.getInspectionFlag())
				.build();
		//onsiteItemService.save(onsiteItem);
		return ResponseBeanBuilder.ok(onsiteItemService.save(onsiteItem));
	}

	@ApiOperation(value = "取得巡检项目")
	@PostMapping("/getOnsiteItem")
	public ResponseBean<OnsiteItem> getOnsiteItem(@RequestBody OnsiteItemReq req) {
		OnsiteItem onsiteItem = onsiteItemService.getById(req.getId());
		return ResponseBeanBuilder.ok(onsiteItem);
	}
	
	@ApiOperation(value = "修改巡检项目")
	@PostMapping("/updateOnsiteItem")
	public ResponseBean updateOnsiteItem(@RequestBody OnsiteItemReq req) {
		OnsiteItem onsiteItem = OnsiteItem.builder()
				.id(req.getId())
				.itemContent(req.getItemContent())
				.build();
		return ResponseBeanBuilder.ok(onsiteItemService.updateById(onsiteItem));
	}
	
	@ApiOperation(value = "取得巡检项目列表")
	@PostMapping("/getOnsiteItemList")
	public ResponseBean<PageBean<OnsiteItem>> getOnsiteItemList(@RequestBody OnsiteItemReq req) {
		QueryWrapper<OnsiteItem> queryWrapper = new QueryWrapper<>();
		queryWrapper.orderByDesc("id");
        if (req.getTypeFlag() != null) {
        	queryWrapper.eq("type_flag", req.getTypeFlag());
        }
        if (req.getItemContent() != null) {
        	queryWrapper.like("item_content", req.getItemContent());
        }
        
		IPage<OnsiteItem> page = new Page<>(req.getPage(), req.getSize());
        IPage<OnsiteItem> userInfoPage = onsiteItemService.page(page, queryWrapper);
        
        return ResponseBeanBuilder.ok(userInfoPage);
	}
	
	@ApiOperation(value = "取得列表")
	@PostMapping("/getList")
	public ResponseBean<PageBean<OnsiteItemRes>> getList(@RequestBody OnsiteItemReq req) {
		
		return onsiteItemService.getList(req);
	}
	
	

}
